# coding: utf-8

"""
    Honeywell

    This is an api to connect to the Honeywell backend  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import honeywell
from honeywell.models.job_post_parameters import JobPostParameters  # noqa: E501
from honeywell.rest import ApiException

class TestJobPostParameters(unittest.TestCase):
    """JobPostParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test JobPostParameters
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = honeywell.models.job_post_parameters.JobPostParameters()  # noqa: E501
        if include_optional :
            return JobPostParameters(
                count = 56, 
                language = 'OPENQASM 2.0', 
                machine = '0', 
                max_cost = 56, 
                name = '0', 
                notify = True, 
                options = [
                    '0'
                    ], 
                priority = 'high', 
                program = '0'
            )
        else :
            return JobPostParameters(
                language = 'OPENQASM 2.0',
                machine = '0',
                program = '0',
        )

    def testJobPostParameters(self):
        """Test JobPostParameters"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
