# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import openapi_client
from openapi_client.models.qubit import Qubit  # noqa: E501
from openapi_client.rest import ApiException

class TestQubit(unittest.TestCase):
    """Qubit unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Qubit
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = openapi_client.models.qubit.Qubit()  # noqa: E501
        if include_optional :
            return Qubit(
                fidelity_rotation = 1.337, 
                last_reported_fidelity_rotation_datetime = '0', 
                name = 56, 
                pos_x = 1.337, 
                pos_y = 1.337, 
                real_qubit = 56
            )
        else :
            return Qubit(
        )

    def testQubit(self):
        """Test Qubit"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
