# coding: utf-8

"""
    Honeywell

    This is an api to connect to the Honeywell backend  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import honeywell
from honeywell.models.inline_response_default import InlineResponseDefault  # noqa: E501
from honeywell.rest import ApiException

class TestInlineResponseDefault(unittest.TestCase):
    """InlineResponseDefault unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test InlineResponseDefault
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = honeywell.models.inline_response_default.InlineResponseDefault()  # noqa: E501
        if include_optional :
            return InlineResponseDefault(
                error_response = honeywell.models.error_response.ErrorResponse(
                    error = honeywell.models.error_response_error.ErrorResponse_error(
                        code = '0', 
                        text = '0', ), ), 
                job_response = honeywell.models.job_response.JobResponse(
                    job = '0', 
                    status = '0', )
            )
        else :
            return InlineResponseDefault(
        )

    def testInlineResponseDefault(self):
        """Test InlineResponseDefault"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
